@@ -11,6 +11,7 @@ from . import rasteredit
 from . import initial_waterlevels
 from . import structure_control
 from . import boundary_conditions
+from . import leakage
 
 # Define a list of WRAPPERS
 # A wrapper is an object that 'wraps' a certain
@@ -35,4 +36,5 @@ WRAPPERS = (
     + initial_waterlevels.WRAPPERS
     + structure_control.WRAPPERS
     + boundary_conditions.WRAPPERS
+    + leakage.WRAPPERS
 )
